@@ -1,6 +1,6 @@
 package yqlib
 
-func splitDocumentOperator(d *dataTreeNavigator, context Context, expressionNode *ExpressionNode) (Context, error) {
+func splitDocumentOperator(_ *dataTreeNavigator, context Context, _ *ExpressionNode) (Context, error) {
 	log.Debugf("-- splitDocumentOperator")
 
 	var index uint
