@@ -125,20 +125,20 @@ func TestPrinterMultipleFilesInSequence(t *testing.T) {
 
 	el := inputs.Front()
 	elNode := el.Value.(*CandidateNode)
-	elNode.Document = 0
-	elNode.FileIndex = 0
+	elNode.document = 0
+	elNode.fileIndex = 0
 	sample1 := nodeToList(elNode)
 
 	el = el.Next()
 	elNode = el.Value.(*CandidateNode)
-	elNode.Document = 0
-	elNode.FileIndex = 1
+	elNode.document = 0
+	elNode.fileIndex = 1
 	sample2 := nodeToList(elNode)
 
 	el = el.Next()
 	elNode = el.Value.(*CandidateNode)
-	elNode.Document = 0
-	elNode.FileIndex = 2
+	elNode.document = 0
+	elNode.fileIndex = 2
 	sample3 := nodeToList(elNode)
 
 	err = printer.PrintResults(sample1)
@@ -172,22 +172,22 @@ func TestPrinterMultipleFilesInSequenceWithLeadingContent(t *testing.T) {
 
 	el := inputs.Front()
 	elNode := el.Value.(*CandidateNode)
-	elNode.Document = 0
-	elNode.FileIndex = 0
+	elNode.document = 0
+	elNode.fileIndex = 0
 	elNode.LeadingContent = "# go cats\n$yqDocSeparator$\n"
 	sample1 := nodeToList(elNode)
 
 	el = el.Next()
 	elNode = el.Value.(*CandidateNode)
-	elNode.Document = 0
-	elNode.FileIndex = 1
+	elNode.document = 0
+	elNode.fileIndex = 1
 	elNode.LeadingContent = "$yqDocSeparator$\n"
 	sample2 := nodeToList(elNode)
 
 	el = el.Next()
 	elNode = el.Value.(*CandidateNode)
-	elNode.Document = 0
-	elNode.FileIndex = 2
+	elNode.document = 0
+	elNode.fileIndex = 2
 	elNode.LeadingContent = "$yqDocSeparator$\n# cool\n"
 	sample3 := nodeToList(elNode)
 
@@ -390,3 +390,23 @@ func TestPrinterNulSeparatorWithJson(t *testing.T) {
 	writer.Flush()
 	test.AssertResult(t, expected, output.String())
 }
+
+func TestPrinterRootUnwrap(t *testing.T) {
+	var output bytes.Buffer
+	var writer = bufio.NewWriter(&output)
+	printer := NewSimpleYamlPrinter(writer, YamlOutputFormat, true, false, 2, false)
+	node, err := getExpressionParser().ParseExpression(".")
+	if err != nil {
+		panic(err)
+	}
+	streamEvaluator := NewStreamEvaluator()
+	_, err = streamEvaluator.Evaluate("sample", strings.NewReader("'a'"), node, printer, NewYamlDecoder(ConfiguredYamlPreferences))
+	if err != nil {
+		panic(err)
+	}
+
+	writer.Flush()
+	expected := `a
+`
+	test.AssertResult(t, expected, output.String())
+}
